==> haskell-websockets-0.10.0.0-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-websockets.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: websockets
version: 0.10.0.0
id: websockets-0.10.0.0-9eteU7KsU6RJM9kRXxqpqG
key: websockets-0.10.0.0-9eteU7KsU6RJM9kRXxqpqG
license: BSD3
copyright: (c) 2010-2011 Siniša Biđin
           (c) 2011-2013 Jasper Van der Jeugt
           (c) 2011 Steffen Schuldenzucker
           (c) 2011 Alex Lang
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
stability: experimental
homepage: http://jaspervdj.be/websockets
synopsis: A sensible and clean way to write WebSocket-capable servers in Haskell.
description:
    This library allows you to write WebSocket-capable servers.
    .
    An example server:
    <https://github.com/jaspervdj/websockets/blob/master/example/server.lhs>
    .
    An example client:
    <https://github.com/jaspervdj/websockets/blob/master/example/client.hs>
    .
    See also:
    .
    * The specification of the WebSocket protocol:
    <http://www.whatwg.org/specs/web-socket-protocol/>
    .
    * The JavaScript API for dealing with WebSockets:
    <http://www.w3.org/TR/websockets/>
category: Network
author: Siniša Biđin <sinisa@bidin.cc>
        Jasper Van der Jeugt <m@jaspervdj.be>
        Steffen Schuldenzucker <steffen.schuldenzucker@googlemail.com>
        Alex Lang <lang@tsurucapital.com>
exposed: True
exposed-modules:
    Network.WebSockets Network.WebSockets.Connection
    Network.WebSockets.Stream
hidden-modules: Network.WebSockets.Client Network.WebSockets.Http
                Network.WebSockets.Hybi13 Network.WebSockets.Hybi13.Demultiplex
                Network.WebSockets.Hybi13.Mask Network.WebSockets.Protocol
                Network.WebSockets.Server Network.WebSockets.Types
abi: f3662f1e0c641a491f9226d96eb483c0
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/websockets-0.10.0.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/websockets-0.10.0.0
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/websockets-0.10.0.0
hs-libraries: HSwebsockets-0.10.0.0-9eteU7KsU6RJM9kRXxqpqG
depends:
    SHA-1.6.4.2-GSP9nhHyWNEAImBrL9QfXp
    attoparsec-0.13.1.0-8poMzD5ooNXJ4NDLaelDWq base-4.9.0.0
    base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY binary-0.8.3.0
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF bytestring-0.10.8.1
    case-insensitive-1.2.0.7-EiN1BqaYOWgBoqFOLWTmWz containers-0.5.7.1
    entropy-0.3.7-54dsRvsNlllHvcIX99CGiD
    network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG
    random-1.1-54KmMHXjttlERYcr1mvsAe
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
haddock-interfaces: /usr/share/doc/haskell-websockets/html/websockets.haddock
haddock-html: /usr/share/doc/haskell-websockets/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-websockets-0.10.0.0-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-websockets.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: websockets
version: 0.10.0.0
id: websockets-0.10.0.0-AWDg5JavrNQDcraaSZ5ezB
key: websockets-0.10.0.0-AWDg5JavrNQDcraaSZ5ezB
license: BSD3
copyright: (c) 2010-2011 Siniša Biđin
           (c) 2011-2013 Jasper Van der Jeugt
           (c) 2011 Steffen Schuldenzucker
           (c) 2011 Alex Lang
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
stability: experimental
homepage: http://jaspervdj.be/websockets
synopsis: A sensible and clean way to write WebSocket-capable servers in Haskell.
description:
    This library allows you to write WebSocket-capable servers.
    .
    An example server:
    <https://github.com/jaspervdj/websockets/blob/master/example/server.lhs>
    .
    An example client:
    <https://github.com/jaspervdj/websockets/blob/master/example/client.hs>
    .
    See also:
    .
    * The specification of the WebSocket protocol:
    <http://www.whatwg.org/specs/web-socket-protocol/>
    .
    * The JavaScript API for dealing with WebSockets:
    <http://www.w3.org/TR/websockets/>
category: Network
author: Siniša Biđin <sinisa@bidin.cc>
        Jasper Van der Jeugt <m@jaspervdj.be>
        Steffen Schuldenzucker <steffen.schuldenzucker@googlemail.com>
        Alex Lang <lang@tsurucapital.com>
exposed: True
exposed-modules:
    Network.WebSockets Network.WebSockets.Connection
    Network.WebSockets.Stream
hidden-modules: Network.WebSockets.Client Network.WebSockets.Http
                Network.WebSockets.Hybi13 Network.WebSockets.Hybi13.Demultiplex
                Network.WebSockets.Hybi13.Mask Network.WebSockets.Protocol
                Network.WebSockets.Server Network.WebSockets.Types
abi: 2b0307ad4be2812e3abd89f4dd530b23
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/websockets-0.10.0.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/websockets-0.10.0.0
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/websockets-0.10.0.0
hs-libraries: HSwebsockets-0.10.0.0-AWDg5JavrNQDcraaSZ5ezB
depends:
    SHA-1.6.4.2-GSP9nhHyWNEAImBrL9QfXp
    attoparsec-0.13.1.0-IbZnQWsljer1cy7HS9Csat base-4.9.0.0
    base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY binary-0.8.3.0
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF bytestring-0.10.8.1
    case-insensitive-1.2.0.7-43Vuzc2uQwC59iyLU6pVOg containers-0.5.7.1
    entropy-0.3.7-54dsRvsNlllHvcIX99CGiD
    network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG
    random-1.1-54KmMHXjttlERYcr1mvsAe
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
haddock-interfaces: /usr/share/doc/haskell-websockets/html/websockets.haddock
haddock-html: /usr/share/doc/haskell-websockets/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
